<?php
/*
  $Id: information.php,v 1.2 2006/03/23 02:12:26 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/
?>
<!-- information //-->
<?php
  $box_shop_info_query = tep_db_query("select shop_info_id, shop_info_title from " . TABLE_SHOP_INFO . " where shop_info_type = '1'");
  if (tep_db_num_rows($box_shop_info_query)) {
    $cssid = 'informationBox';
    $infobox_header = BOX_HEADING_INFORMATION;

    $infobox_contents = array();
    while($box_shop_info = tep_db_fetch_array($box_shop_info_query)) {
      $infobox_contents[] = array('text' => '<a href="' . tep_href_link(FILENAME_INFORMATION, 'siID=' . $box_shop_info['shop_info_id']) . '">' . $box_shop_info['shop_info_title'] . '</a><br>');
    }
  if (defined("KN_CFG_CONTACT_BY_EMAIL") && (KN_CFG_CONTACT_BY_EMAIL == 'false')) {
  } else {
    $infobox_contents[] = array('text' => '<a href="' . tep_href_link(FILENAME_CONTACT_US) . '">' . BOX_INFORMATION_CONTACT . '</a>');
  }

    new infoBox($cssid, $infobox_contents, $infobox_header);
  }
?>
<!-- information_eof //-->
